DeviceOrientationControls class

Constructors

DeviceOrientationControls(Camera object, GlobalKey<PeripheralsState> listenableKey)

Properties

alphaOffset ↔ double
getter/setter pair
enabled ↔ bool
getter/setter pair
eps ↔ double
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
listenableKey ↔ GlobalKey<PeripheralsState>
getter/setter pair
motionSensors ↔ ThreeJsSensors
getter/setter pair
object ↔ Camera
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screenOrientation ↔ double
getter/setter pair

Methods

connect() → void
disconnect() → void
dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDeviceOrientationChangeEvent(AbsoluteOrientationEvent event) → void
setObjectQuaternion(Quaternion quaternion, double alpha, double beta, double gamma, double orient) → void
toString() → String
A string representation of this object.
inherited
update() → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited