DragControls class

This class can be used to provide a drag'n'drop interaction.

Mixed-in types
  • EventDispatcher

Constructors

DragControls(List<Object3D> objects, Camera camera, GlobalKey<PeripheralsState> listenableKey)
objects - An array of draggable 3D objects.

Properties

camera ↔ Camera
getter/setter pair
enabled ↔ bool
getter/setter pair
getObjects → dynamic
no setter
getRaycaster → dynamic
no setter
hashCode → int
The hash code for this object.
no setterinherited
listenableKey ↔ GlobalKey<PeripheralsState>
getter/setter pair
objects ↔ List<Object3D>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope ↔ DragControls
getter/setter pair
transformGroup ↔ bool
getter/setter pair

Methods

activate() → void
Adds the event listeners of the controls.
addEventListener(String type, Function listener) → void
type - The type of event to listen to.
inherited
clearListeners() → void
Remove all Listeners.
inherited
deactivate() → void
Removes the event listeners of the controls.
dispatchEvent(Event event) → void
event - The event that gets fired.
inherited
dispose() → void
Should be called if the controls is no longer required.
override
hasEventListener(String type, Function listener) → bool
type - The type of event to listen to.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onPointerCancel() → void
onPointerDown(dynamic event) → void
onPointerMove(dynamic event) → void
removeEventListener(String type, Function listener) → void
type - The type of the listener that gets removed.
inherited
toString() → String
A string representation of this object.
inherited
updatePointer(dynamic event) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited