FlyControls class

FlyControls enables a navigation similar to fly modes in DCC tools like Blender. You can arbitrarily transform the camera in 3D space without any limitations (e.g. focus on a specific target).

Constructors

FlyControls(Camera object, GlobalKey<PeripheralsState> listenableKey)
object - The camera to be controlled.

Properties

autoForward ↔ bool
getter/setter pair
domElement → PeripheralsState
no setter
dragToLook ↔ bool
getter/setter pair
eps ↔ double
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
listenableKey ↔ GlobalKey<PeripheralsState>
getter/setter pair
mouseStatus ↔ int
getter/setter pair
movementSpeed ↔ double
getter/setter pair
movementSpeedMultiplier ↔ double
getter/setter pair
moveState ↔ FlyMoveState
getter/setter pair
moveVector ↔ Vector3
getter/setter pair
object ↔ Camera
getter/setter pair
rollSpeed ↔ double
getter/setter pair
rotationVector ↔ Vector3
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tmpQuaternion ↔ Quaternion
getter/setter pair

Methods

contextmenu(dynamic event) → void
deactivate() → void
Should be called if the controls is no longer required.
dispose() → void
keydown(dynamic event) → void
keyup(dynamic event) → void
mousedown(dynamic event) → void
mousemove(dynamic event) → void
mouseup(dynamic event) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
update(double delta) → void
Updates the controls. Usually called in the animation loop.
updateMovementVector() → void
updateRotationVector() → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited